@@ -2,7 +2,7 @@
 
 ########################################################################
 ###                                                                  ###
-### Created by Martin Genet, 2012-2021                               ###
+### Created by Martin Genet, 2012-2022                               ###
 ###                                                                  ###
 ### University of California at San Francisco (UCSF), USA            ###
 ### Swiss Federal Institute of Technology (ETH), Zurich, Switzerland ###
@@ -15,10 +15,6 @@
 ###                                                                  ###
 ########################################################################
 
-from builtins import range
-
-import glob
-import numpy
 import vtk
 
 import myPythonLibrary    as mypy
